==> brmo-stufbg204-1.6.2-sources.jar: nl/egem/stuf/sector/bg/_0204/NNPAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * Niet natuurlijk persoon binnen antwoordbericht
 * 
 * <p>Java class for NNP-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NNP-antwoord">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}NNP-fund">
 *       &lt;sequence>
 *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-fund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="NNPADRCOR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="NNPADRVBL" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="NNPNNPHFD" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="NNPNNPNVN" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NNP-antwoord", propOrder = {
    "nnp",
    "nnpadrcor",
    "nnpadrvbl",
    "nnpnnphfd",
    "nnpnnpnvn"
})
public class NNPAntwoord
    extends NNPFund
{

    @XmlElement(name = "NNP")
    protected List<NNPFund> nnp;
    @XmlElement(name = "NNPADRCOR", nillable = true)
    protected List<ADRRelFund> nnpadrcor;
    @XmlElement(name = "NNPADRVBL", nillable = true)
    protected List<ADRRelFund> nnpadrvbl;
    @XmlElement(name = "NNPNNPHFD", nillable = true)
    protected List<NNPAntwoord.NNPNNPHFD> nnpnnphfd;
    @XmlElement(name = "NNPNNPNVN", nillable = true)
    protected List<NNPAntwoord.NNPNNPNVN> nnpnnpnvn;

    /**
     * Gets the value of the nnp property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnp property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNP().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NNPFund }
     * 
     * 
     */
    public List<NNPFund> getNNP() {
        if (nnp == null) {
            nnp = new ArrayList<NNPFund>();
        }
        return this.nnp;
    }

    /**
     * Gets the value of the nnpadrcor property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpadrcor property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPADRCOR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRRelFund }
     * 
     * 
     */
    public List<ADRRelFund> getNNPADRCOR() {
        if (nnpadrcor == null) {
            nnpadrcor = new ArrayList<ADRRelFund>();
        }
        return this.nnpadrcor;
    }

    /**
     * Gets the value of the nnpadrvbl property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpadrvbl property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPADRVBL().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRRelFund }
     * 
     * 
     */
    public List<ADRRelFund> getNNPADRVBL() {
        if (nnpadrvbl == null) {
            nnpadrvbl = new ArrayList<ADRRelFund>();
        }
        return this.nnpadrvbl;
    }

    /**
     * Gets the value of the nnpnnphfd property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpnnphfd property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPNNPHFD().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NNPAntwoord.NNPNNPHFD }
     * 
     * 
     */
    public List<NNPAntwoord.NNPNNPHFD> getNNPNNPHFD() {
        if (nnpnnphfd == null) {
            nnpnnphfd = new ArrayList<NNPAntwoord.NNPNNPHFD>();
        }
        return this.nnpnnphfd;
    }

    /**
     * Gets the value of the nnpnnpnvn property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpnnpnvn property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPNNPNVN().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NNPAntwoord.NNPNNPNVN }
     * 
     * 
     */
    public List<NNPAntwoord.NNPNNPNVN> getNNPNNPNVN() {
        if (nnpnnpnvn == null) {
            nnpnnpnvn = new ArrayList<NNPAntwoord.NNPNNPNVN>();
        }
        return this.nnpnnpnvn;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPHFD
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPNVN
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/NNPAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * Niet natuurlijk persoon binnen antwoordbericht
 * 
 * <p>Java class for NNP-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NNP-antwoord"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}NNP-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-fund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="NNPADRCOR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="NNPADRVBL" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="NNPNNPHFD" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="NNPNNPNVN" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NNP-antwoord", propOrder = {
    "nnp",
    "nnpadrcor",
    "nnpadrvbl",
    "nnpnnphfd",
    "nnpnnpnvn"
})
public class NNPAntwoord
    extends NNPFund
{

    @XmlElement(name = "NNP")
    protected List<NNPFund> nnp;
    @XmlElement(name = "NNPADRCOR", nillable = true)
    protected List<ADRRelFund> nnpadrcor;
    @XmlElement(name = "NNPADRVBL", nillable = true)
    protected List<ADRRelFund> nnpadrvbl;
    @XmlElement(name = "NNPNNPHFD", nillable = true)
    protected List<NNPAntwoord.NNPNNPHFD> nnpnnphfd;
    @XmlElement(name = "NNPNNPNVN", nillable = true)
    protected List<NNPAntwoord.NNPNNPNVN> nnpnnpnvn;

    /**
     * Gets the value of the nnp property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnp property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNP().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NNPFund }
     * 
     * 
     */
    public List<NNPFund> getNNP() {
        if (nnp == null) {
            nnp = new ArrayList<NNPFund>();
        }
        return this.nnp;
    }

    /**
     * Gets the value of the nnpadrcor property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpadrcor property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPADRCOR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRRelFund }
     * 
     * 
     */
    public List<ADRRelFund> getNNPADRCOR() {
        if (nnpadrcor == null) {
            nnpadrcor = new ArrayList<ADRRelFund>();
        }
        return this.nnpadrcor;
    }

    /**
     * Gets the value of the nnpadrvbl property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpadrvbl property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPADRVBL().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRRelFund }
     * 
     * 
     */
    public List<ADRRelFund> getNNPADRVBL() {
        if (nnpadrvbl == null) {
            nnpadrvbl = new ArrayList<ADRRelFund>();
        }
        return this.nnpadrvbl;
    }

    /**
     * Gets the value of the nnpnnphfd property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpnnphfd property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPNNPHFD().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NNPAntwoord.NNPNNPHFD }
     * 
     * 
     */
    public List<NNPAntwoord.NNPNNPHFD> getNNPNNPHFD() {
        if (nnpnnphfd == null) {
            nnpnnphfd = new ArrayList<NNPAntwoord.NNPNNPHFD>();
        }
        return this.nnpnnphfd;
    }

    /**
     * Gets the value of the nnpnnpnvn property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpnnpnvn property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPNNPNVN().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NNPAntwoord.NNPNNPNVN }
     * 
     * 
     */
    public List<NNPAntwoord.NNPNNPNVN> getNNPNNPNVN() {
        if (nnpnnpnvn == null) {
            nnpnnpnvn = new ArrayList<NNPAntwoord.NNPNNPNVN>();
        }
        return this.nnpnnpnvn;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPHFD
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPNVN
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

    }

}
